@@ -103,7 +103,7 @@ class Update_(BaseMessage):
 
     @property
     def value(self):
-        return util.extract_value(self.raw.val)
+        return util.extract_value(self.raw)
     val = value
     
     @property
@@ -211,7 +211,10 @@ class SubscribeResponse_(BaseMessage):
     # @property
     # def sync_response(self):
     #     pass
-    
+    @property
+    def sync_response(self) -> bool:
+        return self.raw.sync_response
+
     @property
     def update(self):
         return Notification_(self.raw.update)
