@@ -3,29 +3,32 @@
 # Arista Networks, Inc. Confidential and Proprietary.
 
 from ssl import OP_ALL
-from typing import List, Optional, Tuple, Any
+from typing import Dict, Optional, Tuple, Any
 from typing_extensions import TypedDict
 from gnmi.messages import Path_
 
+Auth = Tuple[str, Optional[str]]
+
+Target = Tuple[str, int]
+
+Metadata = Dict[str, Any]
+
 class CertificateStore(TypedDict, total=False):
     certificat_chain: bytes
     private_key: bytes
     root_certificates: bytes
 
-
-Auth = Tuple[str, Optional[str]]
-
-Target = Tuple[str, int]
-
-Metadata = List[Tuple[str, Any]]
-
-
 class Options(TypedDict, total=False):
     prefix: Any
     encoding: str
     extension: list
 
 
+class GetOptions(Options, total=False):
+    type: str
+    use_models: list
+
+
 class SubscribeOptions(Options, total=False):
     aggregate: bool
     heartbeat: Optional[int]
@@ -38,10 +41,6 @@ class SubscribeOptions(Options, total=False):
     use_alias: bool
 
 
-class GetOptions(Options, total=False):
-    type: str
-    use_models: list
-
 class GrpcOptions(TypedDict, total=False):
     server_host_override: str
     
